@@ -4,7 +4,7 @@ function(output)
 k<-output$L 
 p<-nrow(output$H)
 ni<-output$ni
-h<-p*k+p+(3*sum(ni)-k )                     
+h<-p*k+p+(3*sum(ni)-3*k )                     
 pen<-2*h
 lik<-output$l[length(output$l)]
 bic<--2*lik+pen
